@@ -117,7 +117,7 @@ weight: 3
 }
 
 // replaceAll replaces all occurrences of new with old, for all files in dir
-func replaceAll(dir string, old, new string) error {
+func replaceAll(dir, old, new string) error {
 	logrus.Infof("Replacing %q with %q", old, new)
 	return filepath.Walk(dir, func(path string, info fs.FileInfo, err error) error {
 		if err != nil {
@@ -133,7 +133,7 @@ func replaceAll(dir string, old, new string) error {
 		if err != nil {
 			return err
 		}
-		out := bytes.Replace(in, []byte(old), []byte(new), -1)
+		out := bytes.ReplaceAll(in, []byte(old), []byte(new))
 		err = os.WriteFile(path, out, 0o644)
 		if err != nil {
 			return err
