@@ -10,7 +10,6 @@ import (
 
 	"github.com/cheggaaa/pb/v3/termutil"
 	"github.com/lima-vm/lima/pkg/store"
-	"github.com/lithammer/dedent"
 	"github.com/mattn/go-isatty"
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
@@ -38,17 +37,17 @@ func newListCommand() *cobra.Command {
 		Use:     "list [flags] [INSTANCE]...",
 		Aliases: []string{"ls"},
 		Short:   "List instances of Lima.",
-		Long: "List instances of Lima.\n" + dedent.Dedent(`
-		The output can be presented in one of several formats, using the --format <format> flag.
+		Long: `List instances of Lima.
 
-		  --format json  - output in json format
-		  --format yaml  - output in yaml format
-		  --format table - output in table format
-		  --format '{{ <go template> }}' - if the format begins and ends with '{{ }}', then it is used as a go template.
-`) + store.FormatHelp + dedent.Dedent(`
-		The following legacy flags continue to function:
-		  --json - equal to '--format json'
-		`),
+The output can be presented in one of several formats, using the --format <format> flag.
+
+  --format json  - output in json format
+  --format yaml  - output in yaml format
+  --format table - output in table format
+  --format '{{ <go template> }}' - if the format begins and ends with '{{ }}', then it is used as a go template.
+` + store.FormatHelp + `
+The following legacy flags continue to function:
+  --json - equal to '--format json'`,
 		Args:              WrapArgsError(cobra.ArbitraryArgs),
 		RunE:              listAction,
 		ValidArgsFunction: listBashComplete,
@@ -125,6 +124,7 @@ func listAction(cmd *cobra.Command, args []string) error {
 	}
 
 	instanceNames := []string{}
+	unmatchedInstances := false
 	if len(args) > 0 {
 		for _, arg := range args {
 			matches := instanceMatches(arg, allinstances)
@@ -132,6 +132,7 @@ func listAction(cmd *cobra.Command, args []string) error {
 				instanceNames = append(instanceNames, matches...)
 			} else {
 				logrus.Warnf("No instance matching %v found.", arg)
+				unmatchedInstances = true
 			}
 		}
 	} else {
@@ -142,6 +143,9 @@ func listAction(cmd *cobra.Command, args []string) error {
 		for _, instName := range instanceNames {
 			fmt.Fprintln(cmd.OutOrStdout(), instName)
 		}
+		if unmatchedInstances {
+			os.Exit(1)
+		}
 		return nil
 	}
 
@@ -175,7 +179,12 @@ func listAction(cmd *cobra.Command, args []string) error {
 			}
 		}
 	}
-	return store.PrintInstances(out, instances, format, &options)
+
+	err = store.PrintInstances(out, instances, format, &options)
+	if err == nil && unmatchedInstances {
+		os.Exit(1)
+	}
+	return err
 }
 
 func listBashComplete(cmd *cobra.Command, _ []string, _ string) ([]string, cobra.ShellCompDirective) {
