@@ -56,7 +56,7 @@ func (s *ServiceWatcher) getServiceInformer() cache.SharedIndexInformer {
 func (s *ServiceWatcher) Start() {
 	const retryInterval = 10 * time.Second
 	const pollImmediately = false
-	wait.PollUntilContextCancel(context.TODO(), retryInterval, pollImmediately, func(ctx context.Context) (done bool, err error) {
+	_ = wait.PollUntilContextCancel(context.TODO(), retryInterval, pollImmediately, func(ctx context.Context) (done bool, err error) {
 		kubeClient, err := tryGetKubeClient()
 		if err != nil {
 			logrus.Tracef("failed to get kube client: %v, will retry in %v", err, retryInterval)
