@@ -38,8 +38,37 @@ const (
 
 var IPv4loopback1 = net.IPv4(127, 0, 0, 1)
 
+func defaultCPUType() CPUType {
+	cpuType := map[Arch]string{
+		AARCH64: "cortex-a72",
+		ARMV7L:  "cortex-a7",
+		// Since https://github.com/lima-vm/lima/pull/494, we use qemu64 cpu for better emulation of x86_64.
+		X8664:   "qemu64",
+		RISCV64: "rv64", // FIXME: what is the right choice for riscv64?
+	}
+	for arch := range cpuType {
+		if IsNativeArch(arch) && IsAccelOS() {
+			if HasHostCPU() {
+				cpuType[arch] = "host"
+			} else if HasMaxCPU() {
+				cpuType[arch] = "max"
+			}
+		}
+		if arch == X8664 && runtime.GOOS == "darwin" {
+			switch cpuType[arch] {
+			case "host", "max":
+				// Disable pdpe1gb on Intel Mac
+				// https://github.com/lima-vm/lima/issues/1485
+				// https://stackoverflow.com/a/72863744/5167443
+				cpuType[arch] += ",-pdpe1gb"
+			}
+		}
+	}
+	return cpuType
+}
+
 func defaultContainerdArchives() []File {
-	const nerdctlVersion = "1.7.5"
+	const nerdctlVersion = "1.7.6"
 	location := func(goos string, goarch string) string {
 		return "https://github.com/containerd/nerdctl/releases/download/v" + nerdctlVersion + "/nerdctl-full-" + nerdctlVersion + "-" + goos + "-" + goarch + ".tar.gz"
 	}
@@ -47,12 +76,12 @@ func defaultContainerdArchives() []File {
 		{
 			Location: location("linux", "amd64"),
 			Arch:     X8664,
-			Digest:   "sha256:adb246a4ef15b8f3d7eed4c6b61173014a6cf343e43ad95eae2087b454dcae5d",
+			Digest:   "sha256:2c841e097fcfb5a1760bd354b3778cb695b44cd01f9f271c17507dc4a0b25606",
 		},
 		{
 			Location: location("linux", "arm64"),
 			Arch:     AARCH64,
-			Digest:   "sha256:ff38142440b4705e12782b7a71074849e712a42ccb69a11306343a8d9f81d8ab",
+			Digest:   "sha256:77c747f09853ee3d229d77e8de0dd3c85622537d82be57433dc1fca4493bab95",
 		},
 		// No arm-v7
 		// No riscv64
@@ -185,31 +214,7 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 		}
 	}
 
-	cpuType := map[Arch]string{
-		AARCH64: "cortex-a72",
-		ARMV7L:  "cortex-a7",
-		// Since https://github.com/lima-vm/lima/pull/494, we use qemu64 cpu for better emulation of x86_64.
-		X8664:   "qemu64",
-		RISCV64: "rv64", // FIXME: what is the right choice for riscv64?
-	}
-	for arch := range cpuType {
-		if IsNativeArch(arch) && IsAccelOS() {
-			if HasHostCPU() {
-				cpuType[arch] = "host"
-			} else if HasMaxCPU() {
-				cpuType[arch] = "max"
-			}
-		}
-		if arch == X8664 && runtime.GOOS == "darwin" {
-			switch cpuType[arch] {
-			case "host", "max":
-				// Disable pdpe1gb on Intel Mac
-				// https://github.com/lima-vm/lima/issues/1485
-				// https://stackoverflow.com/a/72863744/5167443
-				cpuType[arch] += ",-pdpe1gb"
-			}
-		}
-	}
+	cpuType := defaultCPUType()
 	var overrideCPUType bool
 	for k, v := range d.CPUType {
 		if len(v) > 0 {
@@ -508,29 +513,11 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 	iface := make(map[string]int)
 	for _, nw := range append(append(d.Networks, y.Networks...), o.Networks...) {
 		if i, ok := iface[nw.Interface]; ok {
-			if nw.VNLDeprecated != "" {
-				networks[i].VNLDeprecated = nw.VNLDeprecated
-				networks[i].SwitchPortDeprecated = nw.SwitchPortDeprecated
-				networks[i].Socket = ""
-				networks[i].Lima = ""
-			}
 			if nw.Socket != "" {
-				if nw.VNLDeprecated != "" {
-					// We can't return an error, so just log it, and prefer `socket` over `vnl`
-					logrus.Errorf("Network %q has both vnl=%q and socket=%q fields; ignoring vnl",
-						nw.Interface, nw.VNLDeprecated, nw.Socket)
-				}
 				networks[i].Socket = nw.Socket
-				networks[i].VNLDeprecated = ""
-				networks[i].SwitchPortDeprecated = 0
 				networks[i].Lima = ""
 			}
 			if nw.Lima != "" {
-				if nw.VNLDeprecated != "" {
-					// We can't return an error, so just log it, and prefer `lima` over `vnl`
-					logrus.Errorf("Network %q has both vnl=%q and lima=%q fields; ignoring vnl",
-						nw.Interface, nw.VNLDeprecated, nw.Lima)
-				}
 				if nw.Socket != "" {
 					// We can't return an error, so just log it, and prefer `lima` over `socket`
 					logrus.Errorf("Network %q has both socket=%q and lima=%q fields; ignoring socket",
@@ -538,8 +525,6 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 				}
 				networks[i].Lima = nw.Lima
 				networks[i].Socket = ""
-				networks[i].VNLDeprecated = ""
-				networks[i].SwitchPortDeprecated = 0
 			}
 			if nw.MACAddress != "" {
 				networks[i].MACAddress = nw.MACAddress
