@@ -59,15 +59,10 @@ func TestFillDefault(t *testing.T) {
 
 	// Builtin default values
 	builtin := LimaYAML{
-		VMType: ptr.Of("qemu"),
-		OS:     ptr.Of(LINUX),
-		Arch:   ptr.Of(arch),
-		CPUType: map[Arch]string{
-			AARCH64: "cortex-a72",
-			ARMV7L:  "cortex-a7",
-			X8664:   "qemu64",
-			RISCV64: "rv64",
-		},
+		VMType:             ptr.Of("qemu"),
+		OS:                 ptr.Of(LINUX),
+		Arch:               ptr.Of(arch),
+		CPUType:            defaultCPUType(),
 		CPUs:               ptr.Of(defaultCPUs()),
 		Memory:             ptr.Of(defaultMemoryAsString()),
 		Disk:               ptr.Of(defaultDiskSizeAsString()),
@@ -108,19 +103,6 @@ func TestFillDefault(t *testing.T) {
 		},
 		Plain: ptr.Of(false),
 	}
-	if IsAccelOS() {
-		if HasHostCPU() {
-			builtin.CPUType[arch] = "host"
-		} else if HasMaxCPU() {
-			builtin.CPUType[arch] = "max"
-		}
-		if arch == X8664 && runtime.GOOS == "darwin" {
-			switch builtin.CPUType[arch] {
-			case "host", "max":
-				builtin.CPUType[arch] += ",-pdpe1gb"
-			}
-		}
-	}
 
 	defaultPortForward := PortForward{
 		GuestIP:        IPv4loopback1,
@@ -298,7 +280,7 @@ func TestFillDefault(t *testing.T) {
 		VMType: ptr.Of("vz"),
 		OS:     ptr.Of("unknown"),
 		Arch:   ptr.Of("unknown"),
-		CPUType: map[Arch]string{
+		CPUType: CPUType{
 			AARCH64: "arm64",
 			ARMV7L:  "armhf",
 			X8664:   "amd64",
@@ -377,10 +359,8 @@ func TestFillDefault(t *testing.T) {
 		},
 		Networks: []Network{
 			{
-				VNLDeprecated:        "/tmp/vde.ctl",
-				SwitchPortDeprecated: 65535,
-				MACAddress:           "11:22:33:44:55:66",
-				Interface:            "def0",
+				MACAddress: "11:22:33:44:55:66",
+				Interface:  "def0",
 			},
 		},
 		DNS: []net.IP{
@@ -489,7 +469,7 @@ func TestFillDefault(t *testing.T) {
 		VMType: ptr.Of("qemu"),
 		OS:     ptr.Of(LINUX),
 		Arch:   ptr.Of(arch),
-		CPUType: map[Arch]string{
+		CPUType: CPUType{
 			AARCH64: "uber-arm",
 			ARMV7L:  "armv8",
 			X8664:   "pentium",
@@ -645,8 +625,6 @@ func TestFillDefault(t *testing.T) {
 	// o.Networks[1] is overriding the d.Networks[0].Lima entry for the "def0" interface
 	expect.Networks = append(append(d.Networks, y.Networks...), o.Networks[0])
 	expect.Networks[0].Lima = o.Networks[1].Lima
-	expect.Networks[0].VNLDeprecated = ""
-	expect.Networks[0].SwitchPortDeprecated = 0
 
 	// Only highest prio DNS are retained
 	expect.DNS = o.DNS
