@@ -7,31 +7,31 @@ import (
 )
 
 type LimaYAML struct {
-	VMType             *VMType         `yaml:"vmType,omitempty" json:"vmType,omitempty"`
-	OS                 *OS             `yaml:"os,omitempty" json:"os,omitempty"`
-	Arch               *Arch           `yaml:"arch,omitempty" json:"arch,omitempty"`
-	Images             []Image         `yaml:"images" json:"images"` // REQUIRED
-	CPUType            map[Arch]string `yaml:"cpuType,omitempty" json:"cpuType,omitempty"`
-	CPUs               *int            `yaml:"cpus,omitempty" json:"cpus,omitempty"`
-	Memory             *string         `yaml:"memory,omitempty" json:"memory,omitempty"` // go-units.RAMInBytes
-	Disk               *string         `yaml:"disk,omitempty" json:"disk,omitempty"`     // go-units.RAMInBytes
-	AdditionalDisks    []Disk          `yaml:"additionalDisks,omitempty" json:"additionalDisks,omitempty"`
-	Mounts             []Mount         `yaml:"mounts,omitempty" json:"mounts,omitempty"`
-	MountType          *MountType      `yaml:"mountType,omitempty" json:"mountType,omitempty"`
-	MountInotify       *bool           `yaml:"mountInotify,omitempty" json:"mountInotify,omitempty"`
-	SSH                SSH             `yaml:"ssh,omitempty" json:"ssh,omitempty"` // REQUIRED (FIXME)
-	Firmware           Firmware        `yaml:"firmware,omitempty" json:"firmware,omitempty"`
-	Audio              Audio           `yaml:"audio,omitempty" json:"audio,omitempty"`
-	Video              Video           `yaml:"video,omitempty" json:"video,omitempty"`
-	Provision          []Provision     `yaml:"provision,omitempty" json:"provision,omitempty"`
-	UpgradePackages    *bool           `yaml:"upgradePackages,omitempty" json:"upgradePackages,omitempty"`
-	Containerd         Containerd      `yaml:"containerd,omitempty" json:"containerd,omitempty"`
-	GuestInstallPrefix *string         `yaml:"guestInstallPrefix,omitempty" json:"guestInstallPrefix,omitempty"`
-	Probes             []Probe         `yaml:"probes,omitempty" json:"probes,omitempty"`
-	PortForwards       []PortForward   `yaml:"portForwards,omitempty" json:"portForwards,omitempty"`
-	CopyToHost         []CopyToHost    `yaml:"copyToHost,omitempty" json:"copyToHost,omitempty"`
-	Message            string          `yaml:"message,omitempty" json:"message,omitempty"`
-	Networks           []Network       `yaml:"networks,omitempty" json:"networks,omitempty"`
+	VMType             *VMType       `yaml:"vmType,omitempty" json:"vmType,omitempty"`
+	OS                 *OS           `yaml:"os,omitempty" json:"os,omitempty"`
+	Arch               *Arch         `yaml:"arch,omitempty" json:"arch,omitempty"`
+	Images             []Image       `yaml:"images" json:"images"` // REQUIRED
+	CPUType            CPUType       `yaml:"cpuType,omitempty" json:"cpuType,omitempty"`
+	CPUs               *int          `yaml:"cpus,omitempty" json:"cpus,omitempty"`
+	Memory             *string       `yaml:"memory,omitempty" json:"memory,omitempty"` // go-units.RAMInBytes
+	Disk               *string       `yaml:"disk,omitempty" json:"disk,omitempty"`     // go-units.RAMInBytes
+	AdditionalDisks    []Disk        `yaml:"additionalDisks,omitempty" json:"additionalDisks,omitempty"`
+	Mounts             []Mount       `yaml:"mounts,omitempty" json:"mounts,omitempty"`
+	MountType          *MountType    `yaml:"mountType,omitempty" json:"mountType,omitempty"`
+	MountInotify       *bool         `yaml:"mountInotify,omitempty" json:"mountInotify,omitempty"`
+	SSH                SSH           `yaml:"ssh,omitempty" json:"ssh,omitempty"` // REQUIRED (FIXME)
+	Firmware           Firmware      `yaml:"firmware,omitempty" json:"firmware,omitempty"`
+	Audio              Audio         `yaml:"audio,omitempty" json:"audio,omitempty"`
+	Video              Video         `yaml:"video,omitempty" json:"video,omitempty"`
+	Provision          []Provision   `yaml:"provision,omitempty" json:"provision,omitempty"`
+	UpgradePackages    *bool         `yaml:"upgradePackages,omitempty" json:"upgradePackages,omitempty"`
+	Containerd         Containerd    `yaml:"containerd,omitempty" json:"containerd,omitempty"`
+	GuestInstallPrefix *string       `yaml:"guestInstallPrefix,omitempty" json:"guestInstallPrefix,omitempty"`
+	Probes             []Probe       `yaml:"probes,omitempty" json:"probes,omitempty"`
+	PortForwards       []PortForward `yaml:"portForwards,omitempty" json:"portForwards,omitempty"`
+	CopyToHost         []CopyToHost  `yaml:"copyToHost,omitempty" json:"copyToHost,omitempty"`
+	Message            string        `yaml:"message,omitempty" json:"message,omitempty"`
+	Networks           []Network     `yaml:"networks,omitempty" json:"networks,omitempty"`
 	// `network` was deprecated in Lima v0.7.0, removed in Lima v0.14.0. Use `networks` instead.
 	Env          map[string]string `yaml:"env,omitempty" json:"env,omitempty"`
 	DNS          []net.IP          `yaml:"dns,omitempty" json:"dns,omitempty"`
@@ -51,6 +51,8 @@ type (
 	VMType    = string
 )
 
+type CPUType = map[Arch]string
+
 const (
 	LINUX OS = "Linux"
 
@@ -233,20 +235,15 @@ type CopyToHost struct {
 }
 
 type Network struct {
-	// `Lima`, `Socket`, and `VNL` are mutually exclusive; exactly one is required
+	// `Lima` and `Socket` are mutually exclusive; exactly one is required
 	Lima string `yaml:"lima,omitempty" json:"lima,omitempty"`
 	// Socket is a QEMU-compatible socket
 	Socket string `yaml:"socket,omitempty" json:"socket,omitempty"`
 	// VZNAT uses VZNATNetworkDeviceAttachment. Needs VZ. No root privilege is required.
 	VZNAT *bool `yaml:"vzNAT,omitempty" json:"vzNAT,omitempty"`
 
-	// VNLDeprecated is a Virtual Network Locator (https://github.com/rd235/vdeplug4/commit/089984200f447abb0e825eb45548b781ba1ebccd).
-	// On macOS, only VDE2-compatible form (optionally with vde:// prefix) is supported.
-	// VNLDeprecated is deprecated. Use Socket.
-	VNLDeprecated        string `yaml:"vnl,omitempty" json:"vnl,omitempty"`
-	SwitchPortDeprecated uint16 `yaml:"switchPort,omitempty" json:"switchPort,omitempty"` // VDE Switch port, not TCP/UDP port (only used by VDE networking)
-	MACAddress           string `yaml:"macAddress,omitempty" json:"macAddress,omitempty"`
-	Interface            string `yaml:"interface,omitempty" json:"interface,omitempty"`
+	MACAddress string `yaml:"macAddress,omitempty" json:"macAddress,omitempty"`
+	Interface  string `yaml:"interface,omitempty" json:"interface,omitempty"`
 }
 
 type HostResolver struct {
@@ -260,15 +257,3 @@ type CACertificates struct {
 	Files          []string `yaml:"files,omitempty" json:"files,omitempty"`
 	Certs          []string `yaml:"certs,omitempty" json:"certs,omitempty"`
 }
-
-// DEPRECATED types below
-
-// Types have been renamed to turn all references to the old names into compiler errors,
-// and to avoid accidental usage in new code.
-
-type VDEDeprecated struct {
-	VNL        string `yaml:"vnl,omitempty" json:"vnl,omitempty"`
-	SwitchPort uint16 `yaml:"switchPort,omitempty" json:"switchPort,omitempty"` // VDE Switch port, not TCP/UDP port
-	MACAddress string `yaml:"macAddress,omitempty" json:"macAddress,omitempty"`
-	Name       string `yaml:"name,omitempty" json:"name,omitempty"`
-}
