@@ -132,9 +132,16 @@ func loadCache() {
 		if cache.err != nil {
 			return
 		}
-		cache.err = yaml.UnmarshalWithOptions(b, &cache.config, yaml.Strict())
+		cache.err = yaml.UnmarshalWithOptions(b, &cache.config, yaml.DisallowDuplicateKey())
 		if cache.err != nil {
 			cache.err = fmt.Errorf("cannot parse %q: %w", configFile, cache.err)
+			return
+		}
+		var strictConfig YAML
+		if strictErr := yaml.UnmarshalWithOptions(b, &strictConfig, yaml.Strict()); strictErr != nil {
+			// Allow non-existing YAML fields, as a config created with Lima < v0.22 contains `vdeSwitch` and `vdeVMNet`.
+			// These fields were removed in Lima v0.22.
+			logrus.WithError(strictErr).Warn("Non-strict YAML is deprecated and will be unsupported in a future version of Lima: " + configFile)
 		}
 		cache.config, cache.err = fillDefaults(cache.config)
 		if cache.err != nil {
@@ -172,20 +179,3 @@ func Usernet(name string) (bool, error) {
 	}
 	return cache.config.Usernet(name)
 }
-
-// VDESock returns a vde socket.
-//
-// Deprecated: Use Sock.
-func VDESock(name string) (string, error) {
-	loadCache()
-	if cache.err != nil {
-		return "", cache.err
-	}
-	if err := cache.config.Check(name); err != nil {
-		return "", err
-	}
-	if cache.config.Paths.VDEVMNet == "" {
-		return "", errors.New("vdeVMnet is not set")
-	}
-	return cache.config.VDESock(name), nil
-}
