@@ -20,18 +20,23 @@ func EvaluateExpression(expression string, content []byte) ([]byte, error) {
 	}
 	tmpYAMLPath := tmpYAMLFile.Name()
 	defer os.RemoveAll(tmpYAMLPath)
-	err = os.WriteFile(tmpYAMLPath, content, 0o600)
+	_, err = tmpYAMLFile.Write(content)
 	if err != nil {
 		return nil, err
 	}
+	if err = tmpYAMLFile.Close(); err != nil {
+		return nil, err
+	}
 
 	memory := logging.NewMemoryBackend(0)
 	backend := logging.AddModuleLevel(memory)
 	logging.SetBackend(backend)
 	yqlib.InitExpressionParser()
 
-	indent := 2
-	encoder := yqlib.NewYamlEncoder(indent, false, yqlib.ConfiguredYamlPreferences)
+	encoderPrefs := yqlib.ConfiguredYamlPreferences.Copy()
+	encoderPrefs.Indent = 2
+	encoderPrefs.ColorsEnabled = false
+	encoder := yqlib.NewYamlEncoder(encoderPrefs)
 	out := new(bytes.Buffer)
 	printer := yqlib.NewPrinter(encoder, yqlib.NewSinglePrinterWriter(out))
 	decoder := yqlib.NewYamlDecoder(yqlib.ConfiguredYamlPreferences)
